'''
DESCRIPTION

    Miscellaneous things is too small to classify.
'''

from stat import S_IRUSR, S_IWUSR, S_IRGRP, S_IWGRP, S_IROTH

URL_SLASH = '/'
UTF_8 = 'utf-8'
LOGFILE_MODE = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH
